Literally [black](https://black.readthedocs.io/en/stable/), with tabs.

Almost the same [hilosophy](./TODO.md), but different takes.
## Styling
anti-pep8
## License

MIT


## [Original] Black's Authors

The author list is quite long nowadays, so it lives in its own file.

See [AUTHORS.md](./AUTHORS.md)

## Code of Conduct

Everyone participating in the _Black_ project, and in particular in the issue tracker,
pull requests, and social media activity, is expected to treat other people with respect
and more generally to follow the guidelines articulated in the
[Python Community Code of Conduct](https://www.python.org/psf/codeofconduct/).

.
